Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AuthorityUrl ¶
func ResourceManagerUrl ¶
Types ¶
type Config ¶
type Config struct {
ApplicationId string // The Application Id that the Azure app registration portal assigned when the app was registered.
Authority string // The Azure ActiveDirectory Authority URL
ClientSecret string // The Application Secret that was generated for the app in the app registration portal.
ClientCert string // The certificate uploaded to the app registration portal."
ClientKey string // The key for a certificate uploaded to the app registration portal."
ClientKeyPass string // The passphrase to use in conjuction with the associated key of a certificate uploaded to the app registration portal."
Graph string // The Microsoft Graph URL
JWT string // The JSON web token that will be used to authenticate requests sent to Azure APIs
Management string // The Azure ResourceManager URL
MgmtGroupId []string // The Management Group Id to use as a filter
Password string // The password associated with the user principal name associated with the Azure portal.
ProxyUrl string // The forward proxy url
RefreshToken string // The refresh token that will be used to authenticate requests sent to Azure APIs
Region string // The region of the Azure Cloud deployment.
SubscriptionId []string // The Subscription Id(s) to use as a filter
Tenant string // The directory tenant that you want to request permission from. This can be in GUID or friendly name format
Username string // The user principal name associated with the Azure portal.
}
func (Config) AuthorityUrl ¶
func (Config) ResourceManagerUrl ¶
Click to show internal directories.
Click to hide internal directories.